**Example 1: 基于模版创建工作空间**

创建工作空间

Input: 

```
tccli cloudstudio CreateWorkspace --cli-unfold-argument  \
    --Name workspace-name
```

Output: 
```
{
    "Response": {
        "Name": "workspace-name",
        "SpaceKey": "tfyiyw",
        "RequestId": "26881c75-375d-48ad-9a24-7270176e4fab"
    }
}
```

